"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var index_exports = {};
__export(index_exports, {
  camelCaseToWords: () => camelCaseToWords,
  capitalizeFirstLetter: () => capitalizeFirstLetter,
  replaceUnderscoresAndHyphensWithSpaces: () => replaceUnderscoresAndHyphensWithSpaces,
  retryWhenFailed: () => retryWhenFailed,
  tryParseJson: () => tryParseJson
});
module.exports = __toCommonJS(index_exports);

// src/json.ts
function tryParseJson(value, defaultValue = null) {
  try {
    const parsed = JSON.parse(value);
    if (parsed === void 0 || parsed === null) {
      return defaultValue;
    }
    return parsed;
  } catch (err) {
    return defaultValue;
  }
}

// src/retry.ts
async function retryWhenFailed(fn, maxRetries = 5, initialSleepTime = 1e3, stopOnError) {
  let attempt = 0;
  while (attempt < maxRetries) {
    try {
      return await fn();
    } catch (e) {
      if (typeof stopOnError === "function") {
        const error = e;
        if (stopOnError(error)) {
          throw error;
        }
      }
      attempt += 1;
      if (attempt >= maxRetries) {
        throw e;
      }
      const jitter = Math.random();
      const delay = 2 ** attempt * initialSleepTime * jitter;
      await new Promise((resolve) => setTimeout(resolve, delay));
    }
  }
  throw new Error("Retry failed");
}

// src/string.ts
function capitalizeFirstLetter(val) {
  return String(val).charAt(0).toUpperCase() + String(val).slice(1);
}
function camelCaseToWords(s) {
  const result = s.replace(/([a-z])([A-Z])/g, "$1 $2");
  const withSpaces = result.replace(/([A-Z])([a-z])/g, " $1$2");
  const capitalized = capitalizeFirstLetter(withSpaces);
  return capitalized.replace(/\s+/g, " ").trim();
}
function replaceUnderscoresAndHyphensWithSpaces(s) {
  return s.replace(/[-_]/g, " ");
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  camelCaseToWords,
  capitalizeFirstLetter,
  replaceUnderscoresAndHyphensWithSpaces,
  retryWhenFailed,
  tryParseJson
});
//# sourceMappingURL=index.cjs.map