"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/package-manager.ts
var package_manager_exports = {};
__export(package_manager_exports, {
  emptyDir: () => emptyDir,
  formatTargetDir: () => formatTargetDir,
  getPackageManager: () => getPackageManager,
  getPackageManagerExecutable: () => getPackageManagerExecutable,
  installDependencies: () => installDependencies,
  isEmpty: () => isEmpty,
  isPackageInstalled: () => isPackageInstalled,
  setName: () => setName
});
module.exports = __toCommonJS(package_manager_exports);

// src/package-manager/download-and-extract.ts
var import_promises3 = require("fs/promises");
var import_node_path3 = require("path");

// src/filesystem/project-root.ts
var import_node_path = require("path");
var import_find_up = require("find-up");
async function projectRoot(fallbackToCwd = false, cwd) {
  const packageJsonPath = await (0, import_find_up.findUp)("package.json", { cwd });
  if (!packageJsonPath) {
    if (fallbackToCwd) {
      return process.cwd();
    }
    throw new Error("Unable to find project root (no package.json found)");
  }
  return (0, import_node_path.dirname)(packageJsonPath);
}

// src/filesystem/exists.ts
var import_promises = require("fs/promises");
async function exists(path) {
  try {
    await (0, import_promises.stat)(path);
    return true;
  } catch {
    return false;
  }
}

// src/filesystem/mono-repo.ts
var import_promises2 = require("fs/promises");
var import_node_path2 = require("path");
var import_find_up2 = require("find-up");
var import_glob = require("glob");

// src/package-manager/download-and-extract.ts
function formatTargetDir(targetDir) {
  return targetDir?.trim().replace(/\/+$/g, "");
}
async function isEmpty(path) {
  const files = await (0, import_promises3.readdir)(path);
  return files.length === 0 || files.length === 1 && files[0] === ".git";
}
async function emptyDir(dir) {
  if (!await exists(dir)) return;
  for (const file of await (0, import_promises3.readdir)(dir)) {
    if (file === ".git") continue;
    await (0, import_promises3.rm)((0, import_node_path3.resolve)(dir, file), { recursive: true, force: true });
  }
}

// src/package-manager/get-package-manager.ts
var import_detect = require("package-manager-detector/detect");
async function getPackageManager(targetDir) {
  const packageManager = await (0, import_detect.detect)({ cwd: targetDir || process.cwd() });
  return packageManager?.name ?? "npm";
}

// src/package-manager/get-package-manager-executable.ts
async function getPackageManagerExecutable(targetDir) {
  const packageManager = await getPackageManager(targetDir ?? process.cwd());
  switch (packageManager) {
    case "pnpm":
      return { command: "pnpm", args: ["dlx"] };
    case "bun":
      return { command: "bunx", args: [] };
    case "yarn":
      return { command: "yarn", args: ["create"] };
  }
  return { command: "npx", args: [] };
}

// src/package-manager/install-dependencies.ts
var import_install_pkg = require("@antfu/install-pkg");

// src/terminal/ascii.ts
var import_yoctocolors = require("yoctocolors");

// src/terminal/mask-tokens.ts
var maskTokens = (output) => {
  return output.replace(/sm_(pat|aat|sat)_[0-9a-zA-Z]+/g, "***");
};

// src/terminal/cancel.ts
var import_yoctocolors2 = require("yoctocolors");

// src/terminal/execute-command.ts
var import_node_child_process = require("child_process");

// src/terminal/intro.ts
var import_yoctocolors3 = require("yoctocolors");

// src/terminal/note.ts
var import_yoctocolors4 = require("yoctocolors");
var note = (message, level = "info") => {
  const maskedMessage = maskTokens(message);
  console.log("");
  if (level === "warn") {
    console.warn((0, import_yoctocolors4.yellowBright)(maskedMessage));
    return;
  }
  console.log(maskedMessage);
};

// src/terminal/outro.ts
var import_yoctocolors5 = require("yoctocolors");

// src/terminal/spinner.ts
var import_is_in_ci = __toESM(require("is-in-ci"), 1);
var import_yocto_spinner = __toESM(require("yocto-spinner"), 1);
var import_yoctocolors6 = require("yoctocolors");

// src/terminal/table.ts
var import_console_table_printer = require("console-table-printer");
var import_yoctocolors7 = require("yoctocolors");

// src/package-manager/install-dependencies.ts
async function installDependencies(pkgs, cwd) {
  try {
    await (0, import_install_pkg.installPackage)(pkgs, { silent: true, additionalArgs: ["--exact"], cwd });
  } catch (err) {
    const error = err instanceof Error ? err.message : "Unknown error";
    note(
      `Failed to install ${Array.isArray(pkgs) ? `dependencies '${pkgs.join(", ")}'` : `dependency '${pkgs}'`}: ${error}`,
      "warn"
    );
  }
}

// src/package-manager/is-package-installed.ts
var import_package_json = __toESM(require("@npmcli/package-json"), 1);
async function isPackageInstalled(name, path) {
  const pkgJson = await import_package_json.default.load(path ?? await projectRoot());
  const inDependencies = !!pkgJson.content.dependencies?.[name];
  const inDevDependencies = !!pkgJson.content.devDependencies?.[name];
  const inPeerDependencies = !!pkgJson.content.peerDependencies?.[name];
  return inDependencies || inDevDependencies || inPeerDependencies;
}

// src/package-manager/set-name.ts
var import_package_json2 = __toESM(require("@npmcli/package-json"), 1);
async function setName(name, path) {
  const pkgJson = await import_package_json2.default.load(path ?? await projectRoot());
  pkgJson.update({
    name
  });
  await pkgJson.save();
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  emptyDir,
  formatTargetDir,
  getPackageManager,
  getPackageManagerExecutable,
  installDependencies,
  isEmpty,
  isPackageInstalled,
  setName
});
//# sourceMappingURL=package-manager.cjs.map